@@ -7,6 +7,7 @@ These are necessary to avoid circular imports between core.py and fields.py.
     This module is treated as private API.
     Users should not need to use this module directly.
 """
+import typing
 
 
 class FieldABC:
@@ -31,16 +32,24 @@ class FieldABC:
 class SchemaABC:
     """Abstract base class from which all Schemas inherit."""
 
-    def dump(self, obj, *, many: bool = None):
+    def dump(self, obj, *, many: typing.Optional[bool] = None):
         raise NotImplementedError
 
-    def dumps(self, obj, *, many: bool = None):
+    def dumps(self, obj, *, many: typing.Optional[bool] = None):
         raise NotImplementedError
 
-    def load(self, data, *, many: bool = None, partial=None, unknown=None):
+    def load(
+        self, data, *, many: typing.Optional[bool] = None, partial=None, unknown=None
+    ):
         raise NotImplementedError
 
     def loads(
-        self, json_data, *, many: bool = None, partial=None, unknown=None, **kwargs
+        self,
+        json_data,
+        *,
+        many: typing.Optional[bool] = None,
+        partial=None,
+        unknown=None,
+        **kwargs
     ):
         raise NotImplementedError
